@@ -4,13 +4,15 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v1.4.5';
+our $VERSION = 'v2.0.0';
 
-# update DEPENDENCIES in POD & Build.PL & README
 use Perl6::Export::Attrs;
-use File::Temp qw( tempfile );
+use Narada;
+use Path::Tiny 0.053;
 
-use constant MAXPERM => 0666; ## no critic (ProhibitLeadingZeros)
+use constant IS_NARADA1 => eval { local $SIG{__DIE__}; Narada::detect('narada-1') } || undef;
+use constant CONFIG_DIR => IS_NARADA1 ? 'db' : 'mysql';
+use constant MAXPERM    => 0666; ## no critic (ProhibitLeadingZeros)
 
 my $VAR_NAME = qr{\A(?:(?![.][.]?/)[\w.-]+/)*[\w.-]+\z}xms;
 
@@ -18,35 +20,30 @@ my $VAR_NAME = qr{\A(?:(?![.][.]?/)[\w.-]+/)*[\w.-]+\z}xms;
 sub get_config :Export {
     my ($var) = @_;
     croak 'Usage: get_config(NAME)' if @_ != 1;
-    $var =~ /$VAR_NAME/xms              or croak "bad config: $var";
-    -f "config/$var"                    or croak "no such config: $var";
-    open my $cfg, '<', "config/$var"    or die "open(config/$var): $!\n";
-    local $/ = undef;
-    my $val = <$cfg>;
-    close $cfg                          or die "close: $!\n";
-    return $val;
+    $var =~ /$VAR_NAME/xms              or croak "Bad config: $var";
+    return path("config/$var")->slurp_utf8;
 }
 
 sub get_config_line :Export {
     my ($val) = get_config(@_);
     $val =~ s/\n\s*\z//xms;
-    croak 'config contain more than one line' if $val =~ /\n/xms;
+    croak 'Config contain more than one line' if $val =~ /\n/xms;
     return $val;
 }
 
 sub get_db_config :Export {
     my %db;
-    $db{db} = eval { get_config_line('db/db') };
+    $db{db} = eval { get_config_line(CONFIG_DIR.'/db') };
     if (!defined $db{db} || !length $db{db}) {
         return;
     }
-    $db{login}= get_config_line('db/login');
-    $db{pass} = get_config_line('db/pass');
-    $db{host} = eval { get_config_line('db/host') } || q{};
-    $db{port} = eval { get_config_line('db/port') } || q{};
+    $db{login}= get_config_line(CONFIG_DIR.'/login');
+    $db{pass} = get_config_line(CONFIG_DIR.'/pass');
+    $db{host} = eval { get_config_line(CONFIG_DIR.'/host') } || q{};
+    $db{port} = eval { get_config_line(CONFIG_DIR.'/port') } || q{};
     $db{dsn_nodb}  = 'dbi:mysql:';
-    $db{dsn_nodb} .= ';host='.$db{host} if $db{host}; ## no critic
-    $db{dsn_nodb} .= ';port='.$db{port} if $db{port}; ## no critic
+    $db{dsn_nodb} .= ';host='.$db{host} if $db{host}; ## no critic (ProhibitPostfixControls)
+    $db{dsn_nodb} .= ';port='.$db{port} if $db{port}; ## no critic (ProhibitPostfixControls)
     $db{dsn} = $db{dsn_nodb}.';database='.$db{db};
     return \%db;
 }
@@ -54,14 +51,11 @@ sub get_db_config :Export {
 sub set_config :Export {
     my ($var, $val) = @_;
     croak 'Usage: set_config(NAME, VALUE)' if @_ != 2;
-    $var =~ /$VAR_NAME/xms              or croak "bad config: $var";
-    my ($fh, $filename) = tempfile();
-    print {$fh} $val;
-    close $fh                           or die "close: $!\n";
-    system("mkdir -p \$(dirname config/$var)") == 0
-                                        or die "mkdir: $!\n";
-    rename $filename, "config/$var"     or die "rename to config/${var}: $!\n";
-    chmod MAXPERM & ~umask, "config/$var"  or die "chmod config/${var}: $!\n";
+    $var =~ /$VAR_NAME/xms              or croak "Bad config: $var";
+    my $cfg = path("config/$var");
+    $cfg->parent->mkpath;
+    $cfg->spew_utf8($val);
+    $cfg->chmod(MAXPERM & ~umask);
     return;
 }
 
@@ -78,7 +72,7 @@ Narada::Config - manage project configuration
 
 =head1 VERSION
 
-This document describes Narada::Config version v1.4.5
+This document describes Narada::Config version v2.0.0
 
 
 =head1 SYNOPSIS
@@ -95,7 +89,7 @@ This document describes Narada::Config version v1.4.5
 
 =head1 DESCRIPTION
 
-Project's configuration keept in files under directory 'config/' in
+Project's configuration kept in files under directory 'config/' in
 project root directory. Usually single file contain value for single
 variable (variable name is file name itself).
 
@@ -159,18 +153,6 @@ Return: nothing.
 
 Thrown by set_config() and get_config() on wrong VARIABLE_NAME.
 
-=item C<< no such config: %s >>
-
-Thrown by get_config() if file 'config/VARIABLE_NAME' doesn't exist.
-
-=item C<< open(config/%s): %s >>
-
-=item C<< close: %s >>
-
-=item C<< rename to config/%s: %s >>
-
-Internal errors.
-
 =back
 
 
