@@ -4,27 +4,31 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v1.4.5';
+our $VERSION = 'v2.0.0';
 
-# update DEPENDENCIES in POD & Build.PL & README
-use Time::HiRes qw( sleep );
 use Perl6::Export::Attrs;
-use Fcntl qw(:DEFAULT :flock F_SETFD FD_CLOEXEC);
+use Narada;
+use Fcntl qw( :DEFAULT :flock F_SETFD FD_CLOEXEC );
 use Errno;
+use Time::HiRes qw( sleep );
 
 
-use constant LOCKNEW    => 'var/.lock.new';
-use constant LOCKFILE   => 'var/.lock';
+use constant IS_NARADA1 => eval { local $SIG{__DIE__}; Narada::detect('narada-1') } || undef;
+use constant DIR        => IS_NARADA1 ? 'var/' : q{};
+use constant LOCKNEW    => DIR.'.lock.new';
+use constant LOCKFILE   => DIR.'.lock';
 use constant TICK       => 0.1;
-my $f_lock;
+
+my $F_lock;
+
 
 sub shared_lock :Export {
     my $timeout = shift;
     return 1 if $ENV{NARADA_SKIP_LOCK};
-    sysopen $f_lock, LOCKFILE, O_RDONLY|O_CREAT         or croak "open: $!";
+    sysopen $F_lock, LOCKFILE, O_RDONLY|O_CREAT         or croak "open: $!";
     while (1) {
         next            if -e LOCKNEW;
-        last            if flock $f_lock, LOCK_SH|LOCK_NB;
+        last            if flock $F_lock, LOCK_SH|LOCK_NB;
         $!{EWOULDBLOCK}                                 or croak "flock: $!";
     } continue {
         return          if defined $timeout and (($timeout-=TICK) < TICK);
@@ -35,9 +39,9 @@ sub shared_lock :Export {
 
 sub exclusive_lock :Export {
     return if $ENV{NARADA_SKIP_LOCK};
-    sysopen $f_lock, LOCKFILE, O_WRONLY|O_CREAT         or croak "open: $!";
+    sysopen $F_lock, LOCKFILE, O_WRONLY|O_CREAT         or croak "open: $!";
     while (1) {
-        last if flock $f_lock, LOCK_EX|LOCK_NB;
+        last if flock $F_lock, LOCK_EX|LOCK_NB;
         $!{EWOULDBLOCK}                                 or croak "flock: $!";
         system('touch', LOCKNEW) == 0                   or croak "touch: $!/$?";
         sleep TICK;
@@ -54,8 +58,8 @@ sub unlock_new :Export {
 
 sub unlock :Export {
     return if $ENV{NARADA_SKIP_LOCK};
-    if ($f_lock) {
-        flock $f_lock, LOCK_UN                          or croak "flock: $!";
+    if ($F_lock) {
+        flock $F_lock, LOCK_UN                          or croak "flock: $!";
     }
     return;
 }
@@ -63,8 +67,8 @@ sub unlock :Export {
 sub child_inherit_lock :Export {
     my ($is_inherit) = @_;
     return if $ENV{NARADA_SKIP_LOCK};
-    if ($f_lock) {
-        fcntl $f_lock, F_SETFD, $is_inherit ? 0 : FD_CLOEXEC or croak "fcntl: $!";
+    if ($F_lock) {
+        fcntl $F_lock, F_SETFD, $is_inherit ? 0 : FD_CLOEXEC or croak "fcntl: $!";
     }
     return;
 }
@@ -82,7 +86,7 @@ Narada::Lock - manage project locks
 
 =head1 VERSION
 
-This document describes Narada::Lock version v1.4.5
+This document describes Narada::Lock version v2.0.0
 
 
 =head1 SYNOPSIS
@@ -92,9 +96,9 @@ This document describes Narada::Lock version v1.4.5
 
     shared_lock();
     unlock();
-    shared_lock(0) or die "can't get lock right now";
+    shared_lock(0) or die "Can't get lock right now";
     unlock();
-    shared_lock(5) or die "can't get lock in 5 seconds";
+    shared_lock(5) or die "Can't get lock in 5 seconds";
     unlock();
 
     shared_lock();
@@ -126,8 +130,8 @@ operations required for these locks can be implemented using any
 programming language, so all applications in project (including non-perl
 applications) are able to manage project locks.
 
-Shared lock is set using flock(2) LOCK_SH on file 'var/.lock'.
-Exclusive lock is set using flock(2) LOCK_EX on file 'var/.lock'.
+Shared lock is set using flock(2) LOCK_SH on file C<.lock>.
+Exclusive lock is set using flock(2) LOCK_EX on file C<.lock>.
 
 =head2 FREEZE NEW TASKS
 
@@ -135,13 +139,13 @@ There exists scenario when it's impossible to set exclusive lock:
 if new tasks will start and set shared lock before old tasks will drop shared
 lock (and so shared lock will be set all of time).
 
-To work around this scenario another file 'var/.lock.new' should be used
+To work around this scenario another file C<.lock.new> should be used
 as semaphore - it should be created before trying to set exclusive lock,
 and new tasks shouldn't try to set shared lock while this file exists.
 
 This file should be removed after finishing critical operations - this
 guarantee project data will not change even if system will be rebooted,
-because after reboot existence of file 'var/.lock.new' will prevent from
+because after reboot existence of file C<.lock.new> will prevent from
 starting new tasks with shared locks but not prevent from placing
 exclusive lock again and continue these critical operations.
 
@@ -167,9 +171,9 @@ Return: true if able to get lock.
 Try to get exclusive lock which is required to guarantee consistent project
 state (needed while backup/update/maintenance operations).
 
-Set two locks: create file 'var/.lock.new' which signal other scripts to
+Set two locks: create file C<.lock.new> which signal other scripts to
 not try to set shared lock while this file exists and get LOCK_EX on file
-'var/.lock' to be sure all current tasks finished and unlocked their
+C<.lock> to be sure all current tasks finished and unlocked their
 shared locks.
 
 Will delay until get lock.
@@ -180,7 +184,7 @@ Return: nothing.
 
 =item B<unlock_new>()
 
-Free first lock set by exclusive_lock() (i.e. remove file 'var/.lock.new').
+Free first lock set by exclusive_lock() (i.e. remove file C<.lock.new>).
 This allow other tasks to get shared_lock() after this process exit or
 call unlock().
 
@@ -199,7 +203,7 @@ This is acceptable only if we don't run child in background or if
 child will get own locks on start.
 
 In other cases you should call child_inherit_lock() with true value in
-$is_inherit to force child to inherit our lock (just like djb's `setlock`
+$is_inherit to force child to inherit our lock (just like DJB's `setlock`
 or Pepe's `chpst -[lL]` do).
 Calling child_inherit_lock() with false value in $is_inherit will switch
 back to default behaviour (new child will not inherit FD with lock).
@@ -226,24 +230,6 @@ Return: nothing.
 =back
 
 
-=head1 DIAGNOSTICS
-
-=over
-
-=item C<< open: %s >>
-
-=item C<< flock: %s >>
-
-=item C<< fcntl: %s >>
-
-=item C<< touch: %s >>
-
-Probably directory 'var/' or files 'var/.lock' and 'var/.lock.new' doesn't
-exists or has wrong permissions.
-
-=back
-
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Narada::Lock requires configuration files and directories provided by
@@ -254,6 +240,13 @@ exclusive_lock(), unlock_new(), unlock() and child_inherit_lock() will do
 nothing (shared_lock() will return true).
 
 
+=head1 COMPATIBILITY
+
+Narada 1.x project use C<var/.lock> instead of C<.lock>.
+
+Narada 1.x project use C<var/.lock.new> instead of C<.lock.new>.
+
+
 =head1 SUPPORT
 
 =head2 Bugs / Feature Requests
