@@ -4,16 +4,13 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v1.4.5';
+our $VERSION = 'v2.0.0';
 
-# update DEPENDENCIES in POD & Build.PL & README
 use Narada::Config qw( get_config_line );
 use Log::Fast;
 
 
-if (-f 'config/version') {
-    _init_log();
-}
+_init_log();
 
 
 sub import {
@@ -21,15 +18,16 @@ sub import {
     my $pkg = caller 0;
     no strict 'refs';
     for (@args) {
-        next if !m/\A\$(.*)/xms;
-        *{$pkg.q{::}.$1} = \Log::Fast->global();
+        if (m/\A\$(.*)/xms) {
+                *{$pkg.q{::}.$1} = \Log::Fast->global();
+        }
     }
     return;
 }
 
 sub _init_log {
     my $type = eval { get_config_line('log/type') } || 'syslog';
-    my $path = get_config_line('log/output');
+    my $path = eval { get_config_line('log/output') } || return;
     if ($type eq 'syslog') {
         Log::Fast->global()->config({
             level   => get_config_line('log/level'),
@@ -48,7 +46,7 @@ sub _init_log {
         });
     }
     else {
-        croak "unsupported value '$type' in config/log/type";
+        croak "Unsupported value '$type' in config/log/type";
     }
     return;
 }
@@ -66,7 +64,7 @@ Narada::Log - setup project log
 
 =head1 VERSION
 
-This document describes Narada::Log version v1.4.5
+This document describes Narada::Log version v2.0.0
 
 
 =head1 SYNOPSIS
